@@ -28,6 +28,9 @@
 #include <gtkmm/liststore.h>
 
 
+namespace Glom
+{
+
 class ComboBox_Locale : public Gtk::ComboBox
 {
 public:
@@ -55,5 +58,7 @@ protected:
   Glib::RefPtr<Gtk::ListStore> m_model;
 };
 
+} //namespace Glom
+
 #endif //GLOM_TRANSLATION_COMBOBOX_LOCALE_HH
 
